@@ -8,6 +8,18 @@ from pprint import pprint
 from .message_base import MessageBase
 
 MSG300_NULL = b"\x00"*31
+STATION_TYPE_UNSPECIFIED = 0x00
+STATION_TYPE_EO = 0x01
+STATION_TYPE_IR = 0x02
+STATION_TYPE_EOIR = 0x03
+STATION_TYPE_SAR = 0x04
+STATION_TYPE_FIXED_CAMERA = 0x05
+STATION_TYPE_COMMS_RELAY = 0x06
+STATION_TYPE_DISPENSABLE_PAYLOAD = 0x07
+STATION_TYPE_RECORDER = 0x08
+STATION_TYPE_PAYLOAD_BAY_DOOR = 0x09
+STATION_TYPE_CBRN = 0x0A
+STATION_TYPE_SMS = 0x0B
 
 class Message300(BigEndianStructure, MessageBase):
     _pack_ = 1
